%define anolis_release 2
# on update also change soname in the gsm-makefile.patch
%global ver_major 1
%global ver_minor 0
%global ver_patch 22

Name:           gsm
Version:        %{ver_major}.%{ver_minor}.%{ver_patch}
Release:        %{anolis_release}%{?dist}
Summary:        Shared libraries for GSM speech compressor

License:        MIT
URL:            http://www.quut.com/gsm/
Source:         http://www.quut.com/gsm/%{name}-%{version}.tar.gz
Patch0:         %{name}-makefile.patch
BuildRequires:  gcc
BuildRequires:  make

%global srcver %{ver_major}.%{ver_minor}-pl%{ver_patch}

%description
Contains runtime shared libraries for libgsm, an implementation of
the European GSM 06.10 provisional standard for full-rate speech
transcoding, prI-ETS 300 036, which uses RPE/LTP (residual pulse
excitation/long term prediction) coding at 13 kbit/s.

GSM 06.10 compresses frames of 162 13-bit samples (8 kHz sampling
rate, i.e. a frame rate of 50 Hz) into 260 bits; for compatibility
with typical UNIX applications, our implementation turns frames of 160
16-bit linear samples into 33-byte frames (1650 Bytes/s).
The quality of the algorithm is good enough for reliable speaker
recognition; even music often survives transcoding in recognizable
form (given the bandwidth limitations of 8 kHz sampling rate).

The interfaces offered are a front end modelled after compress(1), and
a library API.  Compression and decompression run faster than realtime
on most SPARCstations.  The implementation has been verified against the
ETSI standard test patterns.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package        tools
Summary:        GSM speech compressor tools

%description    tools
Contains command line utilities for libgsm, an implementation of
the European GSM 06.10 provisional standard for full-rate speech
transcoding, prI-ETS 300 036, which uses RPE/LTP (residual pulse
excitation/long term prediction) coding at 13 kbit/s.

%package        devel
Summary:        Header files and development libraries for libgsm
Requires:       %{name}%{_isa} = %{version}-%{release}

%description    devel
Contains header files and development libraries for libgsm, an
implementation of the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
(residual pulse excitation/long term prediction) coding at 13 kbit/s.

%prep
%setup -n gsm-%{srcver} -q
%patch0 -p1 -b .mk

%build
export LDFLAGS="%{?__global_ldflags}"
%make_build all SO_MAJOR=%{ver_major} SO_MINOR=%{ver_minor} SO_PATCH=%{ver_patch}

%install
export LDFLAGS="%{?__global_ldflags}"
mkdir -p %{buildroot}{%{_bindir},%{_includedir}/gsm,%{_libdir},%{_mandir}/{man1,man3}}

%make_install \
	INSTALL_ROOT=%{buildroot}%{_prefix} \
	GSM_INSTALL_INC=%{buildroot}%{_includedir}/gsm \
	GSM_INSTALL_LIB=%{buildroot}%{_libdir} \
	SO_MAJOR=%{ver_major} SO_MINOR=%{ver_minor} SO_PATCH=%{ver_patch}

# some apps look for this in /usr/include
ln -s gsm/gsm.h %{buildroot}%{_includedir}

echo ".so toast.1" > %{buildroot}%{_mandir}/man1/tcat.1
echo ".so toast.1" > %{buildroot}%{_mandir}/man1/untoast.1

%generate_compatibility_deps

%check
# This is to ensure that the patch creates the proper library version.
[ -f %{buildroot}%{_libdir}/libgsm.so.%{version} ]
export LDFLAGS="%{?__global_ldflags}"
%{__make} addtst

%files
%dir %{abidir}
%license COPYRIGHT
%doc MACHINES
%{_libdir}/libgsm.so.*
%{abidir}/libgsm.dump

%files doc
%doc ChangeLog README

%files tools
%{_bindir}/tcat
%{_bindir}/toast
%{_bindir}/untoast
%{_mandir}/man1/tcat.1*
%{_mandir}/man1/toast.1*
%{_mandir}/man1/untoast.1*
%{abidir}/toast-option.list

%files devel
%dir %{_includedir}/gsm
%{_includedir}/gsm/gsm.h
%{_includedir}/gsm.h
%{_libdir}/libgsm.so
%{_mandir}/man3/gsm.3*
%{_mandir}/man3/gsm_explode.3*
%{_mandir}/man3/gsm_option.3*
%{_mandir}/man3/gsm_print.3*

%changelog
* Mon Feb 06 2023 Kaihao Bai <carlo.bai@linux.alibaba.com> - 1.0.22-2
- optimize spec and corresponding patch

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.0.22-1
- update to 1.0.22

* Fri Apr 08 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.0.19-1
- init from upstream and provides libgsm.so
